.. _voxel image import functions:

I/O to other formats
--------------------

VoxelImage objects support both importing from and exporting to common digital
rock formats, ensuring flexibility in data handling. These functionalities facilitate
compatibility with other software tools, enable seamless data sharing, and support
further analysis outside the RockVerse framework.

.. currentmodule:: rockverse.digitalrock.voxelimage

Import raw data
~~~~~~~~~~~~~~~

.. autofunction:: import_raw

Export to raw data
~~~~~~~~~~~~~~~~~~

.. autofunction:: rockverse.digitalrock.voxelimage.VoxelImage.export_raw
